==> knative-model-6.3.0-sources.jar: io/fabric8/knative/messaging/v1/SubscriptionListFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SubscriptionListFluent<A extends SubscriptionListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Subscription item);
  public A setToItems(Integer index,Subscription item);
  public A addToItems(io.fabric8.knative.messaging.v1.Subscription... items);
  public A addAllToItems(Collection<Subscription> items);
  public A removeFromItems(io.fabric8.knative.messaging.v1.Subscription... items);
  public A removeAllFromItems(Collection<Subscription> items);
  public A removeMatchingFromItems(Predicate<SubscriptionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Subscription> getItems();
  public List<Subscription> buildItems();
  public Subscription buildItem(Integer index);
  public Subscription buildFirstItem();
  public Subscription buildLastItem();
  public Subscription buildMatchingItem(Predicate<SubscriptionBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SubscriptionBuilder> predicate);
  public A withItems(List<Subscription> items);
  public A withItems(io.fabric8.knative.messaging.v1.Subscription... items);
  public Boolean hasItems();
  public SubscriptionListFluent.ItemsNested<A> addNewItem();
  public SubscriptionListFluent.ItemsNested<A> addNewItemLike(Subscription item);
  public SubscriptionListFluent.ItemsNested<A> setNewItemLike(Integer index,Subscription item);
  public SubscriptionListFluent.ItemsNested<A> editItem(Integer index);
  public SubscriptionListFluent.ItemsNested<A> editFirstItem();
  public SubscriptionListFluent.ItemsNested<A> editLastItem();
  public SubscriptionListFluent.ItemsNested<A> editMatchingItem(Predicate<SubscriptionBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SubscriptionFluent<SubscriptionListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/messaging/v1/SubscriptionListFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SubscriptionListFluent<A extends SubscriptionListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Subscription item);
  public A setToItems(int index,Subscription item);
  public A addToItems(io.fabric8.knative.messaging.v1.Subscription... items);
  public A addAllToItems(Collection<Subscription> items);
  public A removeFromItems(io.fabric8.knative.messaging.v1.Subscription... items);
  public A removeAllFromItems(Collection<Subscription> items);
  public A removeMatchingFromItems(Predicate<SubscriptionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Subscription> getItems();
  public List<Subscription> buildItems();
  public Subscription buildItem(int index);
  public Subscription buildFirstItem();
  public Subscription buildLastItem();
  public Subscription buildMatchingItem(Predicate<SubscriptionBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SubscriptionBuilder> predicate);
  public A withItems(List<Subscription> items);
  public A withItems(io.fabric8.knative.messaging.v1.Subscription... items);
  public Boolean hasItems();
  public SubscriptionListFluent.ItemsNested<A> addNewItem();
  public SubscriptionListFluent.ItemsNested<A> addNewItemLike(Subscription item);
  public SubscriptionListFluent.ItemsNested<A> setNewItemLike(int index,Subscription item);
  public SubscriptionListFluent.ItemsNested<A> editItem(int index);
  public SubscriptionListFluent.ItemsNested<A> editFirstItem();
  public SubscriptionListFluent.ItemsNested<A> editLastItem();
  public SubscriptionListFluent.ItemsNested<A> editMatchingItem(Predicate<SubscriptionBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SubscriptionFluent<SubscriptionListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
